==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/LowB/PrimIntegerAdd.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v163	((void*)startLabel+40)
#define ST_v162	((void*)startLabel+68)
#define PS_v161	((void*)startLabel+92)
void FR_Prelude_46primIntegerAdd(void);
extern Node PM_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v163)
,};
Node FN_Prelude_46primIntegerAdd[] = {
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_Prelude_46primIntegerAdd)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50001
, useLabel(ST_v162)
,	/* CT_v163: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_Prelude_46primIntegerAdd[] = {
  CAPTAG(useLabel(FN_Prelude_46primIntegerAdd),2)
, useLabel(PS_v161)
, 0
, 0
, 0
,};
Node PP_Prelude_46primIntegerAdd[] = {
 };
Node PC_Prelude_46primIntegerAdd[] = {
 	/* ST_v162: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(112,114,105,109)
, bytes2word(73,110,116,101)
, bytes2word(103,101,114,65)
, bytes2word(100,100,0,0)
,	/* PS_v161: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46primIntegerAdd)
, useLabel(PC_Prelude_46primIntegerAdd)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "primIntegerAddC" Prelude.primIntegerAdd 2 :: Prelude.Integer -> Prelude.Integer -> Prelude.Integer */
extern NodePtr primIntegerAddC(NodePtr,NodePtr);
#ifdef PROFILE
static SInfo pf_Prelude_46primIntegerAdd = {"Prelude","Prelude.primIntegerAdd","Prelude.Integer"};
#endif
C_HEADER(FR_Prelude_46primIntegerAdd) {
  NodePtr nodeptr;
  NodePtr result;
  NodePtr arg1;
  NodePtr arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (NodePtr)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (NodePtr)nodeptr;

  result = primIntegerAddC(arg1,arg2);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_Prelude_46primIntegerAdd);
  C_RETURN(nodeptr);
}

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/LowB/PrimIntegerAdd.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v168	((void*)startLabel+40)
#define ST_v167	((void*)startLabel+68)
#define PS_v166	((void*)startLabel+92)
void FR_Prelude_46primIntegerAdd(void);
extern Node PM_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v168)
,};
Node FN_Prelude_46primIntegerAdd[] = {
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_Prelude_46primIntegerAdd)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50001
, useLabel(ST_v167)
,	/* CT_v168: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_Prelude_46primIntegerAdd[] = {
  CAPTAG(useLabel(FN_Prelude_46primIntegerAdd),2)
, useLabel(PS_v166)
, 0
, 0
, 0
,};
Node PP_Prelude_46primIntegerAdd[] = {
 };
Node PC_Prelude_46primIntegerAdd[] = {
 	/* ST_v167: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(112,114,105,109)
, bytes2word(73,110,116,101)
, bytes2word(103,101,114,65)
, bytes2word(100,100,0,0)
,	/* PS_v166: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46primIntegerAdd)
, useLabel(PC_Prelude_46primIntegerAdd)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "primIntegerAddC" Prelude.primIntegerAdd 2 :: Prelude.Integer -> Prelude.Integer -> Prelude.Integer */
extern Node* primIntegerAddC(Node*,Node*);
#ifdef PROFILE
static SInfo pf_Prelude_46primIntegerAdd = {"Prelude","Prelude.primIntegerAdd","Prelude.Integer"};
#endif
C_HEADER(FR_Prelude_46primIntegerAdd) {
  NodePtr nodeptr;
  Node* result;
  Node* arg1;
  Node* arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (Node*)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (Node*)nodeptr;

  result = primIntegerAddC(arg1,arg2);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_Prelude_46primIntegerAdd);
  C_RETURN(nodeptr);
}
